from sqlalchemy import Column, Integer, String, Text, ForeignKey, DateTime, Boolean, Enum
from sqlalchemy.sql import func
from sqlalchemy.orm import relationship
import enum

from app.core.models.base import Base

class RepeatType(str, enum.Enum):
    NONE = "none"
    DAILY = "daily"
    WEEKLY = "weekly"
    MONTHLY = "monthly"
    YEARLY = "yearly"

class Reminder(Base):
    __tablename__ = "reminders"

    id = Column(Integer, primary_key=True, index=True)
    title = Column(String(255), nullable=False)
    description = Column(Text, nullable=True)
    reminder_time = Column(DateTime(timezone=True), nullable=False, index=True)
    repeat_type = Column(Enum(RepeatType), default=RepeatType.NONE, nullable=False, index=True)
    rrule = Column(String, nullable=True)
    is_active = Column(Boolean, default=True, index=True)
    created_at = Column(DateTime(timezone=True), server_default=func.now())
    updated_at = Column(DateTime(timezone=True), onupdate=func.now())
    user_id = Column(Integer, ForeignKey("users.id"), nullable=False, index=True)

    notify_in_telegram = Column(Boolean, default=False, nullable=False)
    is_sent = Column(Boolean, default=False, nullable=False, index=True)

    user = relationship("User", back_populates="reminders")

    def __repr__(self):
        return f"<Reminder(id={self.id}, title='{self.title}', reminder_time={self.reminder_time}, notify_telegram={self.notify_in_telegram})>"

